Crate setty_derive
setty_
derive
0.3.9
All Items
Crate Items
Attribute Macros
Derive Macros
Crate
setty_
derive
Attribute Macros

__erase
derive
Special version of
#[derive(..)]
macro. Works just like the standard one, except it will de-duplicate the derives expanded from
Config
and explicit ones.
Derive Macros

Config
Our main workhorse. Derives the attributes based on the set of enabled crate features.
Default
Special version of built-in
#[derive(Default)]
that recognizes
#[config(default = $expr)]
attributes